porerefiner.jobs package
========================

Subpackages
-----------

.. toctree::

   porerefiner.jobs.submitters

Submodules
----------

porerefiner.jobs.epi2me module
------------------------------

.. automodule:: porerefiner.jobs.epi2me
   :members:
   :undoc-members:
   :show-inheritance:

porerefiner.jobs.fda\_specific module
-------------------------------------

.. automodule:: porerefiner.jobs.fda_specific
   :members:
   :undoc-members:
   :show-inheritance:

porerefiner.jobs.generic module
-------------------------------

.. automodule:: porerefiner.jobs.generic
   :members:
   :undoc-members:
   :show-inheritance:

porerefiner.jobs.guppy module
-----------------------------

.. automodule:: porerefiner.jobs.guppy
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: porerefiner.jobs
   :members:
   :undoc-members:
   :show-inheritance:
